==> hinemos_src-4.0.3.tar.gz: HinemosClient/src_jobmanagement/com/clustercontrol/jobmanagement/view/JobHistoryView.java <==
/*

Copyright (C) 2006 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.jobmanagement.view;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.eclipse.jface.action.ActionContributionItem;
import org.eclipse.jface.action.IMenuListener;
import org.eclipse.jface.action.IMenuManager;
import org.eclipse.jface.action.IToolBarManager;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Menu;

import com.clustercontrol.ClusterControlPlugin;
import com.clustercontrol.bean.Property;
import com.clustercontrol.jobmanagement.composite.HistoryComposite;
import com.clustercontrol.jobmanagement.composite.action.JobHistorySelectionChangedListener;
import com.clustercontrol.jobmanagement.preference.JobManagementPreferencePage;
import com.clustercontrol.jobmanagement.view.action.StartJobAction;
import com.clustercontrol.jobmanagement.view.action.StopJobAction;
import com.clustercontrol.view.AutoUpdateView;

/**
 * ジョブ[履歴]ビュークラスです。
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class JobHistoryView extends AutoUpdateView {

	// ログ
	private static Log m_log = LogFactory.getLog( JobHistoryView.class );

	/** ビューID */
	public static final String ID = "com.clustercontrol.jobmanagement.view.JobHistoryView";
	/** ジョブ[履歴]ビュー用のコンポジット */
	private HistoryComposite m_history = null;
	/** フィルタ条件 */
	private Property m_condition = null;

	/**
	 * コンストラクタ
	 */
	public JobHistoryView() {
		super();
	}

	/**
	 * ビューを構築します。
	 * 
	 * @param parent 親コンポジット
	 * 
	 * @see org.eclipse.ui.IWorkbenchPart#createPartControl(org.eclipse.swt.widgets.Composite)
	 * @see com.clustercontrol.view.AutoUpdateView#setInterval(int)
	 * @see com.clustercontrol.view.AutoUpdateView#startAutoReload()
	 * @see #createContextMenu()
	 * @see #update()
	 */
	@Override
	public void createPartControl(Composite parent) {
		GridLayout layout = new GridLayout(1, true);
		parent.setLayout(layout);
		layout.marginHeight = 0;
		layout.marginWidth = 0;

		m_history = new HistoryComposite(parent, SWT.NONE);
		GridData gridData = new GridData();
		gridData.horizontalAlignment = GridData.FILL;
		gridData.verticalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		gridData.grabExcessVerticalSpace = true;
		m_history.setLayoutData(gridData);
		m_history.setView(this);

		//ポップアップメニュー作成
		createContextMenu();

		// ボタン（アクション）を制御するリスナーを登録
		this.m_history.getTableViewer().addSelectionChangedListener(
				new JobHistorySelectionChangedListener());

		//ビューを更新
		this.update();

		// 設定情報反映
		IPreferenceStore store = ClusterControlPlugin.getDefault()
		.getPreferenceStore();

		this.setInterval(store
				.getInt(JobManagementPreferencePage.P_HISTORY_UPDATE_CYCLE));

		if (store.getBoolean(JobManagementPreferencePage.P_HISTORY_UPDATE_FLG)) {
			this.startAutoReload();
		}
	}

	/**
	 * コンテキストメニューを作成します。
	 * 
	 * @see org.eclipse.jface.action.MenuManager
	 * @see org.eclipse.swt.widgets.Menu
	 */
	protected void createContextMenu() {
		MenuManager menuManager = new MenuManager();
		menuManager.setRemoveAllWhenShown(true);
		menuManager.addMenuListener(new IMenuListener() {
			/* (non-Javadoc)
			 * @see org.eclipse.jface.action.IMenuListener#menuAboutToShow(org.eclipse.jface.action.IMenuManager)
			 */
			@Override
			public void menuAboutToShow(IMenuManager manager) {
				//メニュー項目設定
				fillContextMenu(manager);
			}
		});

		Menu menu = menuManager.createContextMenu(m_history.getTable());
		m_history.getTable().setMenu(menu);
	}

	/**
	 * コンテキストメニューに項目を追加します。
	 * 
	 * @param manager メニューマネージャ
	 * 
	 * @see org.eclipse.jface.action.IToolBarManager
	 * @see org.eclipse.jface.action.IMenuManager
	 */
	protected void fillContextMenu(IMenuManager manager) {
		//ビューのアクションのインスタンスを取得
		IToolBarManager toolbar = this.getViewSite().getActionBars()
		.getToolBarManager();
		ActionContributionItem startJobAction = (ActionContributionItem) toolbar
		.find(StartJobAction.ID);
		ActionContributionItem stopJobAction = (ActionContributionItem) toolbar
		.find(StopJobAction.ID);

		//ポップアップメニューにアクションを追加
		manager.add(startJobAction.getAction());
		manager.add(stopJobAction.getAction());
	}

	/**
	 * フィルタ条件を返します。
	 * 
	 * @return フィルタ条件
	 */
	public Property getFilterCondition() {
		return m_condition;
	}

	/**
	 * フィルタ条件を設定します。
	 * 
	 * @param condition フィルタ条件
	 */
	public void setFilterCondition(Property condition) {
		m_condition = condition;
	}

	/**
	 * ビューを更新します。
	 * 
	 * @see com.clustercontrol.jobmanagement.composite.HistoryComposite#update()
	 * @see com.clustercontrol.jobmanagement.composite.HistoryComposite#update(Property)
	 */
	@Override
	public void update() {
		try {
			if (m_condition == null) {
				m_history.update();
			} else {
				m_history.update(m_condition);
			}
		} catch (Exception e) {
			m_log.warn("update(), " + e.getMessage(), e);
		}
	}

	/**
	 * ジョブ[履歴]ビュー用のコンポジットを返します。
	 * 
	 * @return ジョブ[履歴]ビュー用のコンポジット
	 */
	public HistoryComposite getComposite() {
		return m_history;
	}

	/**
	 * ビューのアクションの有効/無効を設定します。
	 * 
	 * @param num 選択イベント数
	 * @param selection ボタン（アクション）を有効にするための情報
	 */
	public void setEnabledAction(int num, ISelection selection) {
		//ビューアクションの使用可/不可を設定
		super.setEnabledAction(StartJobAction.ID, selection);
		super.setEnabledAction(StopJobAction.ID, selection);

		if (num > 0){
			super.setEnabledAction(StartJobAction.ID, true);
			super.setEnabledAction(StopJobAction.ID, true);
		} else {
			super.setEnabledAction(StartJobAction.ID, false);
			super.setEnabledAction(StopJobAction.ID, false);
		}
	}
}

==> hinemos_src-4.1.3.tar.gz: HinemosClient/src_jobmanagement/com/clustercontrol/jobmanagement/view/JobHistoryView.java <==
/*

Copyright (C) 2006 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.jobmanagement.view;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.eclipse.jface.action.ActionContributionItem;
import org.eclipse.jface.action.IMenuListener;
import org.eclipse.jface.action.IMenuManager;
import org.eclipse.jface.action.IToolBarManager;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Menu;

import com.clustercontrol.ClusterControlPlugin;
import com.clustercontrol.bean.Property;
import com.clustercontrol.jobmanagement.composite.HistoryComposite;
import com.clustercontrol.jobmanagement.composite.action.JobHistorySelectionChangedListener;
import com.clustercontrol.jobmanagement.preference.JobManagementPreferencePage;
import com.clustercontrol.jobmanagement.view.action.StartJobAction;
import com.clustercontrol.jobmanagement.view.action.StopJobAction;
import com.clustercontrol.view.AutoUpdateView;

/**
 * ジョブ[履歴]ビュークラスです。
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class JobHistoryView extends AutoUpdateView {

	// ログ
	private static Log m_log = LogFactory.getLog( JobHistoryView.class );

	/** ビューID */
	public static final String ID = "com.clustercontrol.jobmanagement.view.JobHistoryView";
	/** ジョブ[履歴]ビュー用のコンポジット */
	private HistoryComposite m_history = null;
	/** フィルタ条件 */
	private Property m_condition = null;

	/**
	 * コンストラクタ
	 */
	public JobHistoryView() {
		super();
	}

	/**
	 * ビューを構築します。
	 * 
	 * @param parent 親コンポジット
	 * 
	 * @see org.eclipse.ui.IWorkbenchPart#createPartControl(org.eclipse.swt.widgets.Composite)
	 * @see com.clustercontrol.view.AutoUpdateView#setInterval(int)
	 * @see com.clustercontrol.view.AutoUpdateView#startAutoReload()
	 * @see #createContextMenu()
	 * @see #update()
	 */
	@Override
	public void createPartControl(Composite parent) {
		GridLayout layout = new GridLayout(1, true);
		parent.setLayout(layout);
		layout.marginHeight = 0;
		layout.marginWidth = 0;

		m_history = new HistoryComposite(parent, SWT.NONE);
		GridData gridData = new GridData();
		gridData.horizontalAlignment = GridData.FILL;
		gridData.verticalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		gridData.grabExcessVerticalSpace = true;
		m_history.setLayoutData(gridData);
		m_history.setView(this);

		//ポップアップメニュー作成
		createContextMenu();

		// ボタン（アクション）を制御するリスナーを登録
		this.m_history.getTableViewer().addSelectionChangedListener(
				new JobHistorySelectionChangedListener());

		//ビューを更新
		this.update();

		// 設定情報反映
		IPreferenceStore store = ClusterControlPlugin.getDefault()
				.getPreferenceStore();

		this.setInterval(store
				.getInt(JobManagementPreferencePage.P_HISTORY_UPDATE_CYCLE));

		if (store.getBoolean(JobManagementPreferencePage.P_HISTORY_UPDATE_FLG)) {
			this.startAutoReload();
		}
	}

	/**
	 * コンテキストメニューを作成します。
	 * 
	 * @see org.eclipse.jface.action.MenuManager
	 * @see org.eclipse.swt.widgets.Menu
	 */
	private void createContextMenu() {
		MenuManager menuManager = new MenuManager();
		menuManager.setRemoveAllWhenShown(true);
		menuManager.addMenuListener(new IMenuListener() {
			/* (non-Javadoc)
			 * @see org.eclipse.jface.action.IMenuListener#menuAboutToShow(org.eclipse.jface.action.IMenuManager)
			 */
			@Override
			public void menuAboutToShow(IMenuManager manager) {
				//メニュー項目設定
				fillContextMenu(manager);
			}
		});

		Menu menu = menuManager.createContextMenu(m_history.getTable());
		m_history.getTable().setMenu(menu);
	}

	/**
	 * コンテキストメニューに項目を追加します。
	 * 
	 * @param manager メニューマネージャ
	 * 
	 * @see org.eclipse.jface.action.IToolBarManager
	 * @see org.eclipse.jface.action.IMenuManager
	 */
	private void fillContextMenu(IMenuManager manager) {
		//ビューのアクションのインスタンスを取得
		IToolBarManager toolbar = this.getViewSite().getActionBars()
				.getToolBarManager();
		ActionContributionItem startJobAction = (ActionContributionItem) toolbar
				.find(StartJobAction.ID);
		ActionContributionItem stopJobAction = (ActionContributionItem) toolbar
				.find(StopJobAction.ID);

		//ポップアップメニューにアクションを追加
		manager.add(startJobAction.getAction());
		manager.add(stopJobAction.getAction());
	}

	/**
	 * フィルタ条件を返します。
	 * 
	 * @return フィルタ条件
	 */
	public Property getFilterCondition() {
		return m_condition;
	}

	/**
	 * フィルタ条件を設定します。
	 * 
	 * @param condition フィルタ条件
	 */
	public void setFilterCondition(Property condition) {
		m_condition = condition;
	}

	/**
	 * ビューを更新します。
	 * 
	 * @see com.clustercontrol.jobmanagement.composite.HistoryComposite#update()
	 * @see com.clustercontrol.jobmanagement.composite.HistoryComposite#update(Property)
	 */
	@Override
	public void update() {
		try {
			if (m_condition == null) {
				m_history.update();
			} else {
				m_history.update(m_condition);
			}
		} catch (Exception e) {
			m_log.warn("update(), " + e.getMessage(), e);
		}
	}

	/**
	 * ジョブ[履歴]ビュー用のコンポジットを返します。
	 * 
	 * @return ジョブ[履歴]ビュー用のコンポジット
	 */
	public HistoryComposite getComposite() {
		return m_history;
	}

	/**
	 * ビューのアクションの有効/無効を設定します。
	 * 
	 * @param num 選択イベント数
	 * @param selection ボタン（アクション）を有効にするための情報
	 */
	public void setEnabledAction(int num, ISelection selection) {
		//ビューアクションの使用可/不可を設定
		super.setEnabledAction(StartJobAction.ID, selection);
		super.setEnabledAction(StopJobAction.ID, selection);

		if (num > 0){
			super.setEnabledAction(StartJobAction.ID, true);
			super.setEnabledAction(StopJobAction.ID, true);
		} else {
			super.setEnabledAction(StartJobAction.ID, false);
			super.setEnabledAction(StopJobAction.ID, false);
		}
	}
}
